@@ -1227,8 +1227,11 @@ const char    **rxvtlib_init_resources (rxvtlib *o, int argc, const char *const
 
 #ifndef XTERM_REVERSE_VIDEO
 /* this is how we implement reverseVideo */
-    if (o->Options & Opt_reverseVideo)
-	SWAP_IT ((char *) o->rs[Rs_color + Color_fg], (char *) o->rs[Rs_color + Color_bg], (char *) tmp);
+    if (o->Options & Opt_reverseVideo) {
+	tmp = (char *) o->rs[Rs_color + Color_fg];
+	o->rs[Rs_color + Color_fg] = o->rs[Rs_color + Color_bg];
+	o->rs[Rs_color + Color_bg] = (char *) tmp;
+    }
 #endif
 
 /* convenient aliases for setting fg/bg to colors */
