@@ -713,7 +713,7 @@ int find_letter_at_word_start (unsigned char *label, unsigned char *used_keys, i
 int find_hotkey (CWidget * w)
 {
     unsigned char used_keys[MAX_KEYS_IN_DIALOG + 3];
-    char *label;
+    const char *label;
     int n = 0;
     CWidget *p = w;
     label = w->label ? w->label : w->text;	/* text for text-widgets which don't have a label */
@@ -1044,7 +1044,7 @@ Window CFindParentMainWindow (Window parent)
 }
 
 /*recursively destroys a widget and all its descendants */
-void recursive_destroy_widgets (int i)
+static void recursive_destroy_widgets (int i)
 {
     int j;
     while ((j = find_first_child_of (CIndex (i)->winid)))
